Learn R Programming

sNPLS (version 0.1.3)

cv_snpls: Cross-validation for a sNPLS model

Description

Performs cross-validation for a sNPLS model

Usage

cv_snpls(X_npls, Y_npls, ncomp = 1:3, keepJ = 1:ncol(X_npls), keepK = 1:dim(X_npls)[3], nfold = 10, parallel = TRUE, free_cores = 2)

Arguments

X_npls
A three-way array containing the predictors.
Y_npls
A matrix containing the response.
ncomp
A vector with the different number of components to test
keepJ
A vector with the different number of selected variables to test
keepK
A vector with the different number of selected 'times' to test
nfold
Number of folds for the cross-validation
parallel
Should the computations be performed in parallel?
free_cores
If parallel computations are performed how many cores are left unused

Value

A list with the best parameters for the model and the CV error

Examples

Run this code
X_npls<-array(rpois(7500, 10), dim=c(50, 50, 3))

Y_npls<-matrix(2+0.4*X_npls[,5,1]+0.7*X_npls[,10,1]-0.9*X_npls[,15,1]+
0.6*X_npls[,20,1]- 0.5*X_npls[,25,1]+rnorm(50), ncol=1)

cv1<- cv_snpls(X_npls, Y_npls, ncomp=1:2, keepJ = 1:10, keepK = 1:3, parallel = FALSE)

Run the code above in your browser using DataLab