Learn R Programming

sNPLS (version 0.1.3)

plot.sNPLS: Plots for sNPLS model fits

Description

Different plots for sNPLS model fits

Usage

"plot"(x, comps = c(1, 2), type = "T", ...)

Arguments

x
A sNPLS model fit
comps
A vector of length two with the components to plot
type
The type of plot. One of those: "T", "U", "Wj", "Wk" or "time"
...
Options passed to plot

Value

A plot of the type specified in the type parameter