plot_T: Internal function for plot.sNPLS
Description
Internal function for plot.sNPLS
Usage
plot_T(x, comps = c(1, 2), ...)
Arguments
comps
A vector of length two with the components to plot
...
Options passed to plot
Value
A plot of the T matrix of a sNPLS model fit